/*
 * Simple dictionary to keep key/value pairs.
 *
 * This software is distributed under the terms of GNU
 * Public License version 2 or later versions.
 *
 */

#ifndef _DICT_H
#define _DICT_H

typedef int boolean_t; /* Define this type if needed. */

/*
#ifndef FALSE
  #define FALSE	(0)
#endif
#ifndef TRUE
  #define TRUE	(!FALSE)
#endif
*/

struct dict;

typedef void (*dict_destroy_callback_t)(void *data);
typedef int  (*dict_foreach_callback_t)(char **res_key, void **res_value, void *opaque);
typedef int  (*dict_compare_t)(const char *a, const char *b);

struct dict *dict_new(size_t newsize, dict_destroy_callback_t func, dict_compare_t cmp);

int dict_put(struct dict *dict, const char *key, void *value);

int dict_get(struct dict *dict, const char *key, void **res_value);

int dict_get_nth(struct dict *dict, unsigned int nth, void **res_value);

void dict_foreach(struct dict *dict, dict_foreach_callback_t func, void *opaque);

boolean_t dict_rem_key(struct dict *dict, const char *key);

int dict_rem_range(struct dict *dict, unsigned int n, unsigned int count);

size_t dict_size(struct dict *dict);

void dict_destroy(struct dict **dict);

#endif

